@@ -1,3 +1,4 @@
+import logging
 from datetime import datetime
 from typing import List
 
@@ -7,7 +8,7 @@ from .base import DataModel  # noqa: F401
 from .data_models.battery import Battery
 from .data_models.chore import Chore
 from .data_models.generic import EntityType
-from .data_models.meal_items import MealPlanItem, RecipeItem
+from .data_models.meal_items import MealPlanItem, MealPlanSection, RecipeItem
 from .data_models.product import Group, Product, ShoppingListProduct
 from .data_models.task import Task
 from .data_models.user import User  # noqa: F401
@@ -25,12 +26,26 @@ from .grocy_api_client import TaskResponse  # noqa: F401
 from .grocy_api_client import UserDto  # noqa: F401
 from .grocy_api_client import DEFAULT_PORT_NUMBER, GrocyApiClient, TransactionType
 
+_LOGGER = logging.getLogger(__name__)
+_LOGGER.setLevel(logging.INFO)
+
 
 class Grocy(object):
     def __init__(
-        self, base_url, api_key, port: int = DEFAULT_PORT_NUMBER, verify_ssl=True
+        self,
+        base_url,
+        api_key,
+        port: int = DEFAULT_PORT_NUMBER,
+        path: str = None,
+        verify_ssl=True,
+        debug=False,
     ):
-        self._api_client = GrocyApiClient(base_url, api_key, port, verify_ssl)
+        self._api_client = GrocyApiClient(
+            base_url, api_key, port, path, verify_ssl, debug
+        )
+
+        if debug:
+            _LOGGER.setLevel(logging.DEBUG)
 
     def stock(self) -> List[Product]:
         raw_stock = self._api_client.get_stock()
@@ -42,8 +57,8 @@ class Grocy(object):
         return self.due_products(get_details)
 
     def due_products(self, get_details: bool = False) -> List[Product]:
-        raw_due_prodcuts = self._api_client.get_volatile_stock().due_products
-        due_products = [Product(resp) for resp in raw_due_prodcuts]
+        raw_due_products = self._api_client.get_volatile_stock().due_products
+        due_products = [Product(resp) for resp in raw_due_products]
 
         if get_details:
             for item in due_products:
@@ -82,11 +97,16 @@ class Grocy(object):
         if resp:
             return Product(resp)
 
+    def product_by_barcode(self, barcode: str) -> Product:
+        resp = self._api_client.get_product_by_barcode(barcode)
+        if resp:
+            return Product(resp)
+
     def all_products(self) -> List[Product]:
         raw_products = self.get_generic_objects_for_type(EntityType.PRODUCTS)
         from pygrocy.grocy_api_client import ProductData
 
-        product_datas = [ProductData(product) for product in raw_products]
+        product_datas = [ProductData(**product) for product in raw_products]
         return [Product(product) for product in product_datas]
 
     def chores(self, get_details: bool = False) -> List[Chore]:
@@ -128,11 +148,89 @@ class Grocy(object):
         amount: float = 1,
         spoiled: bool = False,
         transaction_type: TransactionType = TransactionType.CONSUME,
+        allow_subproduct_substitution: bool = False,
     ):
         return self._api_client.consume_product(
-            product_id, amount, spoiled, transaction_type
+            product_id, amount, spoiled, transaction_type, allow_subproduct_substitution
         )
 
+    def inventory_product(
+        self,
+        product_id: int,
+        new_amount: int,
+        best_before_date: datetime = None,
+        shopping_location_id: int = None,
+        location_id: int = None,
+        price: int = None,
+        get_details: bool = True,
+    ) -> Product:
+        product = Product(
+            self._api_client.inventory_product(
+                product_id,
+                new_amount,
+                best_before_date,
+                shopping_location_id,
+                location_id,
+                price,
+            )
+        )
+
+        if get_details:
+            product.get_details(self._api_client)
+        return product
+
+    def add_product_by_barcode(
+        self,
+        barcode: str,
+        amount: float,
+        price: float,
+        best_before_date: datetime = None,
+        get_details: bool = True,
+    ) -> Product:
+        product = Product(
+            self._api_client.add_product_by_barcode(
+                barcode, amount, price, best_before_date
+            )
+        )
+
+        if get_details:
+            product.get_details(self._api_client)
+        return product
+
+    def consume_product_by_barcode(
+        self,
+        barcode: str,
+        amount: float = 1,
+        spoiled: bool = False,
+        get_details: bool = True,
+    ) -> Product:
+        product = Product(
+            self._api_client.consume_product_by_barcode(barcode, amount, spoiled)
+        )
+
+        if get_details:
+            product.get_details(self._api_client)
+        return product
+
+    def inventory_product_by_barcode(
+        self,
+        barcode: str,
+        new_amount: int,
+        best_before_date: datetime = None,
+        location_id: int = None,
+        price: int = None,
+        get_details: bool = True,
+    ) -> Product:
+        product = Product(
+            self._api_client.inventory_product_by_barcode(
+                barcode, new_amount, best_before_date, location_id, price
+            )
+        )
+
+        if get_details:
+            product.get_details(self._api_client)
+        return product
+
     def shopping_list(self, get_details: bool = False) -> List[ShoppingListProduct]:
         raw_shoppinglist = self._api_client.get_shopping_list()
         shopping_list = [ShoppingListProduct(resp) for resp in raw_shoppinglist]
@@ -146,10 +244,14 @@ class Grocy(object):
         return self._api_client.add_missing_product_to_shopping_list(shopping_list_id)
 
     def add_product_to_shopping_list(
-        self, product_id: int, shopping_list_id: int = None, amount: int = None
+        self,
+        product_id: int,
+        shopping_list_id: int = None,
+        amount: int = None,
+        quantity_unit_id: int = None,
     ):
         return self._api_client.add_product_to_shopping_list(
-            product_id, shopping_list_id, amount
+            product_id, shopping_list_id, amount, quantity_unit_id
         )
 
     def clear_shopping_list(self, shopping_list_id: int = 1):
@@ -183,7 +285,11 @@ class Grocy(object):
         raw_tasks = self._api_client.get_tasks()
         return [Task(task) for task in raw_tasks]
 
-    def complete_task(self, task_id, done_time):
+    def task(self, task_id: int) -> Task:
+        resp = self._api_client.get_task(task_id)
+        return Task(resp)
+
+    def complete_task(self, task_id, done_time: datetime = datetime.now()):
         return self._api_client.complete_task(task_id, done_time)
 
     def meal_plan(self, get_details: bool = False) -> List[MealPlanItem]:
@@ -225,3 +331,22 @@ class Grocy(object):
 
     def get_generic_objects_for_type(self, entity_type: EntityType):
         return self._api_client.get_generic_objects_for_type(entity_type.value)
+
+    def meal_plan_sections(self) -> List[MealPlanSection]:
+        raw_sections = self._api_client.get_meal_plan_sections()
+        return [MealPlanSection(section) for section in raw_sections]
+
+    def meal_plan_section(self, meal_plan_section_id: int) -> MealPlanSection:
+        section = self._api_client.get_meal_plan_section(meal_plan_section_id)
+
+        if section:
+            return MealPlanSection(section)
+
+    def users(self) -> List[User]:
+        user_dtos = self._api_client.get_users()
+        return [User(user) for user in user_dtos]
+
+    def user(self, user_id: int = None) -> User:
+        user = self._api_client.get_user(user_id=user_id)
+        if user:
+            return User(user)
