@@ -19,10 +19,10 @@ class TestBattery:
         assert battery.name == "Battery1"
         assert battery.description == "Warranty ends 2023"
         assert battery.used_in == "TV remote control"
-        assert battery.charge_interval_days == 0
+        assert battery.charge_interval_days == 180
         assert isinstance(battery.created_timestamp, datetime)
         assert isinstance(battery.last_charged, datetime)
-        assert battery.next_estimated_charge_time is None
+        assert isinstance(battery.next_estimated_charge_time, datetime)
         assert battery.userfields is None
         assert battery.charge_cycles_count == 4
 
