@@ -17,6 +17,12 @@ class TestUtils(TestCase):
 
         assert date_obj is None
 
+    def test_parse_date_empty_string(self):
+        date_str = ""
+        date_obj = utils.parse_date(date_str)
+
+        assert date_obj is None
+
     def test_parse_int_valid(self):
         int_str = "2"
         int_number = utils.parse_int(int_str)
